aboutsummaryrefslogtreecommitdiff
path: root/platform/ext/lpc55s69.cmake
diff options
context:
space:
mode:
Diffstat (limited to 'platform/ext/lpc55s69.cmake')
-rw-r--r--platform/ext/lpc55s69.cmake12
1 files changed, 6 insertions, 6 deletions
diff --git a/platform/ext/lpc55s69.cmake b/platform/ext/lpc55s69.cmake
index 1025d6f9d1..66f72f4d44 100644
--- a/platform/ext/lpc55s69.cmake
+++ b/platform/ext/lpc55s69.cmake
@@ -32,16 +32,16 @@ if(COMPILER STREQUAL "ARMCLANG")
#set(BL2_SCATTER_FILE_NAME "${PLATFORM_DIR}target/nxp/lpcxpresso55s69/Device/Source/armclang/LPC55S69_cm33_core0_bl2.sct")
#set(S_SCATTER_FILE_NAME "${PLATFORM_DIR}target/nxp/lpcxpresso55s69/Device/Source/armclang/LPC55S69_cm33_core0_s.sct")
#set(NS_SCATTER_FILE_NAME "${PLATFORM_DIR}target/nxp/lpcxpresso55s69/Device/Source/armclang/LPC55S69_cm33_core0_ns.sct")
- if (DEFINED CMSIS_5_DIR)
- # Not all projects defines CMSIS_5_DIR, only the ones that use it.
- set (RTX_LIB_PATH "${CMSIS_5_DIR}/CMSIS/RTOS2/RTX/Library/ARM/RTX_V8MMN.lib")
+ if (DEFINED CMSIS_DIR)
+ # Not all projects defines CMSIS_DIR, only the ones that use it.
+ set (RTX_LIB_PATH "${CMSIS_DIR}/RTOS2/RTX/Library/ARM/RTX_V8MMN.lib")
endif()
elseif(COMPILER STREQUAL "GNUARM")
set(S_SCATTER_FILE_NAME "${PLATFORM_DIR}/common/gcc/tfm_common_s.ld")
set(NS_SCATTER_FILE_NAME "${PLATFORM_DIR}/target/nxp/lpcxpresso55s69/Device/Source/armgcc/LPC55S69_cm33_core0_ns.ld")
- if (DEFINED CMSIS_5_DIR)
- # Not all projects define CMSIS_5_DIR, only the ones that use it.
- set(RTX_LIB_PATH "${CMSIS_5_DIR}/CMSIS/RTOS2/RTX/Library/GCC/libRTX_V8MMN.a")
+ if (DEFINED CMSIS_DIR)
+ # Not all projects define CMSIS_DIR, only the ones that use it.
+ set(RTX_LIB_PATH "${CMSIS_DIR}/RTOS2/RTX/Library/GCC/libRTX_V8MMN.a")
endif()
else()
message(FATAL_ERROR "No startup file is available for compiler '${CMAKE_C_COMPILER_ID}'.")